# IO

A module dedicated to various IO operations.

Users are encouraged to use this when trying to import confusion matrices from disk.

## File Formats

::: prob_conf_mat.io.load_csv
    options:
        heading_level: 3
        show_signature: true
        show_signature_annotations: true
        separate_signature: true
        line_length: 80

## Utilities

::: prob_conf_mat.io.validate_confusion_matrix
    options:
        heading_level: 3
        show_signature: true
        show_signature_annotations: true
        separate_signature: true
        line_length: 80

::: prob_conf_mat.io.pred_cond_to_confusion_matrix
    options:
        heading_level: 3
        show_signature: true
        show_signature_annotations: true
        separate_signature: true
        line_length: 80

::: prob_conf_mat.io.confusion_matrix_to_pred_cond
    options:
        heading_level: 3
        show_signature: true
        show_signature_annotations: true
        separate_signature: true
        line_length: 80
